# Rochdi's PIPHelper!
The piphelper module helps you make your own pip package with just some functions!

## Functions

## make function

the make function makes a template of a pip package.

## helper function

the helper function gives you some info about what this does

## build function

the build function builds the project

## upload function

the upload function uploads your project.

## How to Use.

## Step 1. Install

first you need to type on your cli app => "pip install rochdi"

## Step 2. Import

then on your directory, make a python file and put in => "import rochdi.pipmake"

## Step 3. Usage

the usage if you wanna make everything isn"t simple cause it xan get confused, for that you can use the time.sleep() function like below:

![Usage](Usage.png "Usage")

# Issues

there may be some issues buy may come of you. like the twine failing (i have no clue of how i can solve this) like in this video:

<video width="320" height="240" controls>
  <source src="Usage.mp4" type="video/mp4">
</video>